@@ -7,8 +7,9 @@ def _searchbases(cls, accum):
     for base in cls.__bases__:
         _searchbases(base, accum)
 
+
 def getmro(cls):
-    "Return tuple of base classes in method resolution order."
+    """Return tuple of base classes in method resolution order."""
     if hasattr(cls, "__mro__"):
         return cls.__mro__
     else:
